clc
clear all
close all

%% Input info for the beam the damping is computed for
L = 1310; %[m]
E = 210000e6; %[N/m^2]
I = 16.448; %[m^4]
A = 0.5813; %[m^2]
rho = 7850; %[kg/m^3]
m = A*rho; %[kg/m]


%% Taking in information on the damping of the system

% These are the initially guessed values for the damping ratios
xi_p = 0.05;
xi_r = 0.05;

% Taking in information on the eigenfrequencies of the system
%om_p = ((pi/L)^2)*sqrt(E*I/m); 
%om_r = ((10*pi/L)^2)*sqrt(E*I/m);
% The above formulas are applicable for a beam with a rectangular cross section

freq=csvread('Eigenfrequencies.csv',2,0); % If the eigenfrequencies of the system is known and in a .csv file
for i=1:100
    mode(i) = i;
    om(i) = freq(i,3);   
end

% These marks the applied range for the Rayleigh damping
om_p = om(1);
om_r = om(20); 

alpha = (2*om_p*om_r*((om_p*xi_r)-(om_r*xi_p))/((om_p^2)-(om_r^2)));
beta = 2*((om_p*xi_p)-(om_r*xi_r))/((om_p^2)-(om_r^2));

xi_ray_p = (0.5*alpha/om_p)+(0.5*beta*om_p);
xi_ray_r = (0.5*alpha/om_r)+(0.5*beta*om_r);

% If the complex eigenmodes of the system is known they can be read and
% plotted against the Rayleigh damping ratios. Note that the file being
% read here already contains the calculated modal damping ratios
comp=csvread('DampingInModes.csv',1,0);

for i=1:100
    mode(i) = i;
    xi_ray(i) = (0.5*alpha/om(i))+(0.5*beta*om(i)); %Creating the modal Rayleigh damping ratios
    xi_comp(i) = comp(i,5); %Creating the actual modal damping ratios
end

gamma = om_r/om_p;
xi_min = 2*sqrt(gamma)*xi_p/(1+gamma); %Calculates the minimum allowed damping ratio in the Rayleigh damping

% Plots the Rayleigh damping ratios
figure(1)
plot(om(1:50),xi_ray(1:50)*100,'k','linewidth',2)
hold on
scatter(om(1:50),xi_comp(1:50)*100,'r','linewidth',2) %Include if the modal damping ratios also should be plotted
line([om_p,om_p],[0,100*xi_ray_p],'LineStyle','-.','color','k','linewidth',1);
line([om_r,om_r],[0,100*xi_ray_r],'LineStyle','-.','color','k','linewidth',1); %These marks the applied range for the damping
axis([0,om(50),0,10]);
xlabel('\omega_n [rad/s]','FontSize',24);
ylabel('\xi_n [%]','FontSize',24);
legend1 = legend('Rayleigh damping','Damping from complex eigenmodes','location','northwest')
set(legend1,'FontSize',24);