clc
clear all
close all



%%
%Create input file
fid=fopen('MovingCar.inp','wt');  


fprintf(fid, '*Heading \n');
fprintf(fid, '*Restart, read \n'); %Starts the step in succession of the steps in the Hardanger Bridge model

%% Info about Nodes
nset=csvread('nset.csv');
for i=1:size(nset,1)
    node(i)=nset(i,1);
    pos(i) = nset(i,2);
    NodeSet(i,:)=[node(i)];
    NodePos(i,:) = [pos(i)];
end

Length = NodePos(length(NodePos))-NodePos(1);

% Bring in info about cars
%% Cars
fprintf(fid,'** \n');
fprintf(fid,'***CARS***\n');
CarSet=csvread('carSet_Trailer.csv',1,0);
NumOfWheels = size(CarSet,1);
fprintf(fid,'%s %.0f \n','**Number of wheels =',NumOfWheels);
fprintf(fid,'** \n');

fprintf(fid,'**     Wheel, x0 [m], Speed [km/t],  t0 [s],   Wheelforce [N] \n');

if NumOfWheels >= 1
    for i=1:NumOfWheels
        wheel(i)=i;
        x0(i)=CarSet(i,3);
        Force(i)=-CarSet(i,4);
        Speed(i)=CarSet(i,5);
        Steptime(i)=Length/(Speed(i)/3.6);
        t0(i) = x0(i)*Steptime(i)/Length;
        Cars(i,:)=[wheel(i),x0(i),Speed(i),t0(i),Force(i)];
        fprintf(fid,'%s     %.0f,     %.2f,     %.2f,        %.2f,     %.2f \n','**',Cars(i,:));
    end
    fprintf(fid,'** \n');

    t0max = max(t0);
    t0min = min(t0);
    t0sum = sum(t0);
    MeanSteptime = mean(Steptime);
    
else
    fprintf(' \n No cars on the bridge \n');
end

%% History data
fprintf(fid, '** History data \n');
fprintf(fid, '** \n');


%% Creating Car step
format='%.10f,%.2f,%.10f \n';
fprintf(fid, '** \n');
fprintf(fid,'%s \n', '*STEP, Amplitude=Ramp, Inc=30000, Name=Car, Nlgeom=yes');
fprintf(fid, '*Dynamic \n');
fprintf(fid,'%s, %.2f, %s \n', '1e-4', 1.5*(max(Steptime+t0)+t0min), '1e-8, 5e-3');  
fprintf(fid, '** \n');


for c = 1:1:NumOfWheels
%% Creating amplitudes for each node
format='%.3f, %.3f, %.3f, %.3f, %.3f, %.3f \n';
for l=1:1:length(NodeSet)
    amplitude(l)=l;
    amp(l,:)=[amplitude(l)];
    increment(l)=t0(c) + (Steptime(c)*(amp(l)-1)/(length(NodeSet)-1));
    inc(l,:)=[increment(l)];
end

    fprintf(fid,'%s, %s%.0f%s%.0f, %s \n', '*Amplitude', 'Name=Amp-',c,'-',0,'TIME=TOTAL TIME');
    fprintf(fid,'%.3f, %.3f, %.3f, %.3f, %.3f, %.3f \n',inc(1),1,inc(2),0,inc(3),0);

for m=1:2:length(NodeSet)-2

    fprintf(fid,'%s, %s%.0f%s%.0f, %s \n', '*Amplitude', 'name=Amp-',c,'-',m,'TIME=TOTAL TIME');
    fprintf(fid,format,inc(m),0,inc(m+1),1,inc(m+2),0);

end

    fprintf(fid,'%s, %s%.0f%s%.0f, %s \n', '*Amplitude', 'name=Amp-',c,'-',length(NodeSet)-1,'TIME=TOTAL TIME');
    fprintf(fid,'%.3f, %.3f, %.3f, %.3f, %.3f, %.3f \n',inc(length(NodeSet)-2),0,inc(length(NodeSet)-1),1,inc(length(NodeSet)),0);

 

  
%% Loads
% Creating loads in every second node, due to the bridge model using three noded Timoshenko elements
fprintf(fid,'%s, %s%.0f%s%.0f \n', '*Cload', 'Amp=Amp-',c,'-',1-1);
fprintf(fid,'%.0f, %s, %.2f \n',NodeSet(1), '2', Force(c));

fprintf(fid,'** \n');
for n=3:2:length(nset)-2 

% Implementing loads
fprintf(fid,'%s, %s%.0f%s%.0f \n', '*Cload', 'Amp=Amp-',c,'-',n-2);
fprintf(fid,'%.0f, %s, %.2f \n',NodeSet(n), '2', Force(c));

% Implementing moments
fprintf(fid,'%s, %s%.0f%s%.0f \n', '*Cload', 'Amp=Amp-',c,'-',n-2);
fprintf(fid,'%.0f, %s, %.2f \n',NodeSet(n-1), '6', -(NodePos(n)-NodePos(n-1))*Force(c));

fprintf(fid,'%s, %s%.0f%s%.0f \n', '*Cload', 'Amp=Amp-',c,'-',n-2);
fprintf(fid,'%.0f, %s, %.2f \n',NodeSet(n+1), '6', (NodePos(n+1)-NodePos(n))*Force(c));

end

fprintf(fid,'%s, %s%.0f%s%.0f \n', '*Cload', 'Amp=Amp-',c,'-',length(nset)-1-1);
fprintf(fid,'%.0f, %s, %.2f \n',NodeSet(length(nset)-1), '2', Force(c));

end



%% Output
fprintf(fid, '** \n');
fprintf(fid, '** OUTPUT REQUESTS \n');
fprintf(fid, '** \n');
fprintf(fid, '*Restart, write, frequency=0 \n');
fprintf(fid, '** \n');
fprintf(fid, '*El file \n');
fprintf(fid, 'S, \n');
fprintf(fid, '** \n');
fprintf(fid, '** FIELD OUTPUT: CarField \n');
fprintf(fid, '** \n');
fprintf(fid, '*Output, field, variable=PRESELECT \n');
fprintf(fid, '** \n');

fprintf(fid, '*End Step \n');

