function [H,Szz,F] = calcWelch(H,Fs,nIntervals)
% CALCWELCH Calculates the Welch's power spectral density
% estimate for the vertical acceleration response. 
% The script splits the response into a number
% of user-defined intervals for the entire recording.
% 
% INPUT:     H:             Acceleration response on the Hardanger Bridge
%            Fs:            Adjusted samplerate
%            nIntervals:    Number of time intervals
%
% OUTPUT:    H:             Acceleration response, reshaped
%            Szz:           Power spectral density of response
%            F:             Frequency component of power spectral density
%

% Splitting the recording into n intervals

for i = 1:9
    H{i} = reshape(H{i},[],nIntervals);
end

% Calculating spectral densities for the user-defined time interval

for i = 1:9                    % i represents the sensors
    for j = 1:nIntervals        % j represents the time intervals
        [Szz{i}{j},F{i}{j}] = pwelch(H{i}(:,j),[],[],[],Fs);
    end
end