function dispSpecter(section,nIntervals)
% DISPSPECTER Calculates the power spectral density
% for the numerically integrated accelerations and the 
% estimated specter for displacements through the transfer
% function. This function is used as a tool for comparing
% these power spectras and to evaluate the reliability for
% the numerically integrated displacements using acc2disp.
%
% INPUT:    section:        Specifying the section for analysis
%           nIntervals:     Number of time intervals
%

load('Recording');

[Fs,~,t] = setDate(recording);

H = readAcceleration(recording);

for i = 1:9
    D{i} = acc2disp(H{i},Fs);
end

t = reshape(t,[],nIntervals);

% Calculating the power spectral density for the 
% accelerations and displacements.
[D,Sdd,Fdd] = calcWelch(nIntervals,D,Fs);
[H,Saa,Faa] = calcWelch(nIntervals,H,Fs);

H = H{section};
D = D{section};

% Estimating the power spectral density for the displacement 
% through the transfer function
for i = 1:nIntervals
    S_uu(:,i) = Saa{section}{:,i}./((2*pi*Faa{section}{:,i}).^4);
end

for i = 1:nIntervals
    figure;
    hold on
    plot(Fdd{section}{:,i},Sdd{section}{:,i},...
        'Linewidth',4,'color','g')
    plot(Faa{section}{i},S_uu(:,i),'Linewidth',2,'color','k')
    hold off
    xlabel('Frequency [Hz]')
    ylabel('S_{u_{z}}')
    set(gca,'Xlim',[0 1],'Xtick',0:0.2:1,'Fontsize',30,...
        'Linewidth',1)
    legend('Numerical integration','Transfer function',...
        'position','northeast')
end