function [Fs,day,t] = setDate(recording)
% SETDATE Creates vectors for the time interval and sets the date 
% for a recording. The function also retrieves the adjusted samplerate
% from the recording. Requires a matfile for a recording.
%
% INPUT:        recording:      .mat-file for the recording
%
% OUTPUT:       Fs:             Adjusted samplerate
%               day:            String array for the date of recording
%               t:              Time vector for the time of recording
%

% Reading starttime and length of recording for timeseries
date_temp = recording.general.starttime;
duration = recording.general.duration;

% Adjusted samplefreqency
Fs = recording.sensor(1).adjusted_samplerate;   

% Timestep for recording in hours
dt = inv(3600*Fs);

% Converting time recording to be compatible with MATLAB
fileID = textscan(date_temp,'%f/%f/%f %f:%f:%f');

% Rearranging the array for the date and time for recording
day = datetime([fileID{3},fileID{2},fileID{1},fileID{4},...
    fileID{5},fileID{6}]);

% Producing a time vector in the same size as the recording
t = hours(hour(day)+hours(minutes(minute(day)))):hours(dt):...
    hours(hour(day)+hours(minutes(minute(day)))+...
    hours(seconds(duration)));