function trafficCrossCovariance(sensor1,sensor2,starttime,endtime) 
% TRAFFICCROSSCOVARIANCE Creates a figure showing the 
% cross-covariance for the accelerations for two sections.
% The input variables for starttime and endtime is given in minutes.
%
% INPUT:    sensor1:        First section for the analysis
%           sensor2:        Second section for the analysis
%           starttime:      Start time for analysis, in minutes
%           endtime:        End time for analysis, in minutes
%

load('Recording');

[Fs] = setDate(recording);
H = readAcceleration(recording);

section1 = H{sensor1};
section2 = H{sensor2};

l = mean(length(section1),length(section2));
lstart = l*starttime/30+1;
lend = l*endtime/30+1;

t = lstart:lend; % Selecting the interval for the analysis

% Calculating the cross-covariance for the responses
[c11,lag11] = xcov(section1(t),section1(t));
[c12,lag12] = xcov(section1(t),section2(t));
[c21,lag21] = xcov(section2(t),section1(t));
[c22,lag22] = xcov(section2(t),section2(t));

c = {c11 c12 c21 c22};
lag = {lag11 lag12 lag21 lag22};

c_str = [sprintf('%d%d',sensor1,sensor1),...
    sprintf('%d%d',sensor1,sensor2),sprintf('%d%d',sensor2,sensor1),...
    sprintf('%d%d',sensor2,sensor2)];

% Changing units for lag-vector from number of data points to 
% seconds
for i = 1:4
    lag{i} = rdivide(lag{i},Fs);
end

% Plotting the cross-covariance for the two recordings

for i = 1:4
    figure
    plot(lag{i},c{i},'Linewidth',2)
    ylabel('C_{xy}')
    xlabel('Time lag [s]')
    set(gca,'Fontsize',30,'Ylim',[-0.05 0.05],'Ytick',...
        -0.05:0.025:0.05,'Linewidth',1)
end