function trafficSpecter(section,nIntervals)
% TRAFFICSPECTER Creates a plot for the Welch power spectral density
% estimation. The script splits the recording into a user-defined 
% number of segments which is handled by the subroutine calcWelch.
%
% INPUT:    section:        Specifying the section for analysis
%           nIntervals:     Number of time intervals
%

load('Recording');

[Fs,~,t] = setDate(recording);
H = readAcceleration(recording);

% Defining information for time of recording
l = length(t)/nIntervals;

time(1) = t(1);
for i=1:nIntervals
    time(i+1) = ceil(t(i*l));
end

% Calculating the Welch power spectral density estimate
[~,S,F] = calcWelch(nIntervals,H,Fs);

for i = 1:nIntervals
    y(i) = figure;
    plot(F{section}{i},S{section}{i},'Linewidth',2)
    ylabel('$$S_{\ddot{u}_z}$$','Interpreter','latex')
    xlabel('Frequency [Hz]')
    set(gca,'Xtick',0:1:10,'Xlim',[0 10],'Fontsize',45,'Linewidth',2)
%     saveas(y(i),fullfile('Figures','Specter',sprintf('%s-%s',...
%         datestr(time(i),'HH.MM'),datestr(time(i+1),'HH.MM')),...
%         sprintf('H%d.png',section)))
end