function [y1,y2,y3] = windCondition(section,nIntervals)
% WINDCONDITION Creates arrays for the recorded wind data,
% including the wind direction, and horizontal- and vertical wind 
% velocities.
%
% INPUT:    section:        Specifying the section for analysis
%           nIntervals:     Number of time intervals
%
% OUTPUT:   y1:             Vector of plots for horizontal wind velocity
%           y2:             Vector of plots for vertical wind velocity
%           y3:             Vector of plots for wind angle
%

% Loading complete recording from Hardanger Bridge
load('Recording'); 

[~,~,t] = setDate(recording);

l = length(t)/nIntervals;

time(1) = t(1);
for i=1:nIntervals
    time(i+1) = ceil(t(i*l));
end

[u,w,theta] = readWind(recording);

u = u{section};
w = w{section};
theta = theta{section};

u = reshape(u,[],nIntervals);
w = reshape(w,[],nIntervals);
theta = reshape(theta,[],nIntervals);
t = reshape(t,[],nIntervals);

% Plotting the recorded wind responses for a user-defined 
% time interval
for i=1:nIntervals
    % Horizontal wind
    y1(i) = figure;
    plot(t(:,i),u(:,i),'DurationTickFormat','hh:mm:ss')
    ylabel('U [m/s]')
    set(gca,'Fontsize',30,'Linewidth',2,'Ylim',[0 15],'Ytick',0:5:15)
%     saveas(y1(i),fullfile('Figures','Wind','Horizontal_Wind',...
%         sprintf('%s-%s',datestr(time(i),'HH.MM'),...
%         datestr(time(i+1),'HH.MM')),...
%         sprintf('Section_A%d.png',section)))

    % Vertical wind
    y2(i) = figure;
    plot(t(:,i),w(:,i),'DurationTickFormat','hh:mm:ss')
    ylabel('w [m/s]')
    set(gca,'Fontsize',30,'Ylim',[-5 5],'Ytick',-5:5:5,'Linewidth',2)
%     saveas(y2(i),fullfile('Figures','Wind','Vertical_Wind',...
%         sprintf('%s-%s',datestr(time(i),'HH.MM'),...
%         datestr(time(i+1),'HH.MM')),...
%         sprintf('Section_A%d.png',section)))

    % Wind angle
    y3(i) = figure;
    plot(t(:,i),theta(:,i),'DurationTickFormat','hh:mm:ss')
    ylabel('\Theta []','Fontsize',30)
    ylim([0 400])
    set(gca,'Fontsize',30,'Ytick',0:90:360,'Ylim',[0 400],'Linewidth',2)
%     saveas(y3(i),fullfile('Figures','Wind','Wind_Angle',...
%         sprintf('%s-%s',datestr(time(i),'HH.MM'),...
%         datestr(time(i+1),'HH.MM')),...
%         sprintf('Section_A%d.png',section)))
end
